--- vcut/vcut.c.orig	2012-05-19 11:04:34.336204739 -0400
+++ vcut/vcut.c	2012-05-19 11:47:17.884678896 -0400
@@ -202,13 +202,21 @@
 	return 0;
 }
 
+static int will_drop_output(vcut_state *s)
+{
+	return s->drop_output
+		|| !s->output_filename
+		|| (strcmp(s->output_filename, ".") == 0);
+}
+
 /* Opens the given output file; or sets s->drop_output if the filename is ".".
  * Returns 0 for success, or -1 on failure. */
-static int open_output_file(vcut_state *s, char *filename)
+static int open_output_file(vcut_state *s)
 {
 	assert(s->out == NULL);
 
-	if(strcmp(filename, ".") == 0)
+	s->drop_output = 0;
+	if(will_drop_output(s))
 	{
 		s->out = NULL;
 		s->drop_output = 1;
@@ -216,13 +224,13 @@
 
 	else
 	{
-                if(strcmp(filename, "-") == 0)
-                        s->out = fdopen(1, "wb");
-                else
-                        s->out = fopen(filename, "wb");
-		s->drop_output = 0;
+		if(strcmp(s->output_filename, "-") == 0)
+			s->out = fdopen(1, "wb");
+		else
+			s->out = fopen(s->output_filename, "wb");
 		if(!s->out) {
-			fprintf(stderr, _("Couldn't open %s for writing\n"), filename);
+			fprintf(stderr, _("Couldn't open %s for writing\n"),
+					s->output_filename);
 			return -1;
 		}
 	}
@@ -235,7 +243,7 @@
 {
 	if(!s->out && !s->drop_output)
 	{
-		if(open_output_file(s, s->output_filename)!=0)
+		if(open_output_file(s)!=0)
 			return -1;
 	}
 
@@ -407,7 +415,7 @@
 			return -1;
 		}
 
-		if(rel_sample < bs && !s->drop_output)
+		if(rel_sample < bs && !will_drop_output(s))
 		{
 			fprintf(stderr, _("Can't produce a file starting"
 					" and ending between sample positions " FORMAT_INT64
